@@ -9,6 +9,7 @@ from vpc_control_ao.domain.value_obj import (
     CommandResponseStatus
 )
 from ..domain.entity import (
+    DeploymentSetting,
     DatapipeDataInfo,
     DatapipeResponse,
     DatapipeHost,
@@ -103,7 +104,7 @@ from ..domain.value_obj import (
     RestartNumber,
     ImageID,
     GPUType,
-    Time,
+    K3SRunTime,
     InstanceTypeStatus,
     Key,
     InstanceID,
@@ -143,6 +144,7 @@ from ..domain.value_obj import (
     NodeSelectorDict,
 )
 from .dto import (
+    DeploymentSettingDTO,
     DatapipeHostDTO,
     DatapipeResponseDTO,
     DatapipeDataInfoDTO,
@@ -264,7 +266,7 @@ class NodeInfoAssembler(Assembler):
             node_expired_time = None if dto.node_expired_time is None else DateTime(dto.node_expired_time),
             auto_release_time = None if dto.auto_release_time is None else DateTime(dto.auto_release_time),
             key_name = Name(dto.key_name),
-            run_time = Time(dto.run_time),
+            run_time = None if dto.run_time is None else K3SRunTime(dto.run_time),
             k3s_version = Version(dto.k3s_version),
             _life_time = Number(dto._life_time)
         )
@@ -450,10 +452,10 @@ class PodAssembler(Assembler):
     def to_entity(self, dto: PodDTO):
         return Pod(
             name = Name(dto.name),
-            node_name = NodeName(dto.node_name),
+            node_name = None if dto.node_name is None else NodeName(dto.node_name),
             pod_status = PodStatus(dto.pod_status),
             age = DateTime(dto.age),
-            pod_ip = IP(dto.pod_ip),
+            pod_ip = None if dto.pod_ip is None else IP(dto.pod_ip),
             namespace = Name(dto.namespace),
             restarts = RestartNumber(dto.restarts),
             readiness_info = Info(dto.readiness_info),
@@ -477,7 +479,7 @@ class NodeMetaAssembler(Assembler):
         return NodeMeta(
             name = NodeName(dto.name),
             status = NodeStatus(dto.status),
-            run_time = Time(dto.run_time),
+            run_time = K3SRunTime(dto.run_time),
             k3s_version = Version(dto.k3s_version),
             private_ip = IP(dto.private_ip),
             label = NodeLabel(dto.label)
@@ -821,6 +823,28 @@ class ContainerSettingAssembler(Assembler):
         )
 container_setting_assembler = ContainerSettingAssembler()
 
+
+
+class DeploymentSettingAssembler(Assembler):
+    def to_entity(self, dto: DeploymentSettingDTO):
+        return DeploymentSetting(
+            deployment_name=Name(dto.deployment_name),
+            namespace_name=Name(dto.namespace_name),
+            labels=LabelDict(dto.labels),
+            containers=[container_setting_assembler.to_entity(c) for c in dto.containers],
+            init_containers=None if dto.init_containers is None else [container_setting_assembler.to_entity(i) for i in dto.init_containers],
+            node_name = None if dto.node_name is None else Name(dto.node_name),
+            node_selector=None if dto.node_selector is None else NodeSelectorDict(dto.node_selector),
+            replicas=None if dto.replicas is None else Number(dto.replicas),
+            restart_policy=None if dto.restart_policy is None else RestartPolicy(dto.restart_policy),
+            volumes = None if dto.volumes is None else [volume_setting_assembler.to_entity(i) for i in dto.volumes],
+            selector = label_selector_assembler.to_entity(dto.selector),
+            dns_policy = None if dto.dns_policy is None else DNSPolicy(dto.dns_policy),
+            service_account_name = None if dto.service_account_name is None else ServiceAccountName(dto.service_account_name)
+        )
+deployment_setting_assembler = DeploymentSettingAssembler()
+    
+
 class JobSettingAssembler(Assembler):
     def to_entity(self, dto: JobSettingDTO):
         return JobSetting(
