@@ -3,12 +3,15 @@ from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from ddd_objects.lib import get_random_string
 from vpc_control_ao.domain.entity import (
+    CommandRequest,
+    CommandItem,
     Condition,
     CommandResponse,
     CommandHost,
     InstanceUserSetting,
-    InstanceInfo
+    InstanceInfo,
 )
+from vpc_control_ao.domain.entity_ext import PipelineActionOutput, _PipelineStage
 from .value_obj import (
     AccountID,
     AccountSecret,
@@ -56,7 +59,7 @@ from .value_obj import (
     RestartNumber,
     ImageID,
     GPUType,
-    Time,
+    K3SRunTime,
     InstanceTypeStatus,
     Key,
     InstanceID,
@@ -95,57 +98,6 @@ from .value_obj import (
     NodeSelectorDict
 )
 
-# class Condition(Entity):
-#     def __init__(
-#         self,
-#         min_cpu_num: Number,
-#         max_cpu_num: Number,
-#         min_memory_size: Size,
-#         max_memory_size: Size,
-#         min_gpu_num: Optional[Number] = None,
-#         max_gpu_num: Optional[Number] = None,
-#         min_gpu_memory_size: Optional[Size] = None,
-#         max_gpu_memory_size: Optional[Size] = None
-#     ):
-#         self.min_cpu_num=min_cpu_num
-#         self.max_cpu_num=max_cpu_num
-#         self.min_memory_size=min_memory_size
-#         self.max_memory_size=max_memory_size
-#         self.min_gpu_num=min_gpu_num
-#         self.max_gpu_num=max_gpu_num
-#         self.min_gpu_memory_size=min_gpu_memory_size
-#         self.max_gpu_memory_size=max_gpu_memory_size
-
-# class InstanceUserSetting(Entity):
-#     def __init__(
-#         self,
-#         name: Name,
-#         password: Password,
-#         image_id: ImageID,
-#         region_id: RegionID,
-#         exclude_instance_types: List[InstanceType],
-#         user_data: Optional[Data] = None,
-#         internet_pay_type: Type = Type('PayByTraffic'),
-#         amount: InstanceAmount = InstanceAmount(1),
-#         bandwidth_in: BandWidth = BandWidth(200),
-#         bandwidth_out: BandWidth = BandWidth(1),
-#         disk_size: Size = Size(20),
-#         key_name: Name = Name('ansible'),
-#         inner_connection: Bool = Bool(True)
-#     ):
-#         self.name=name
-#         self.password=password
-#         self.image_id=image_id
-#         self.region_id=region_id
-#         self.exclude_instance_types=exclude_instance_types
-#         self.user_data=user_data
-#         self.internet_pay_type=internet_pay_type
-#         self.amount=amount
-#         self.bandwidth_in=bandwidth_in
-#         self.bandwidth_out=bandwidth_out
-#         self.disk_size=disk_size
-#         self.key_name=key_name
-#         self.inner_connection=inner_connection
 
 
 class NodeUserSetting(Entity):
@@ -157,7 +109,7 @@ class NodeUserSetting(Entity):
         disk_size: Size = Size(20),
         bandwidth_in: BandWidth = BandWidth(200),
         bandwidth_out: BandWidth = BandWidth(1),
-        image_id: ImageID = ImageID('centos_8_5_x64_20G_alibase_20220303.vhd'),
+        image_id: ImageID = ImageID('ubuntu_20_04_x64_20G_alibase_20221107.vhd'),
         node_type: NodeType = NodeType('worker'),
         postfix: Bool = Bool(True),
         diff_instance_type: Bool = Bool(False),
@@ -243,7 +195,7 @@ class NodeInfo(ExpiredEntity):
         node_expired_time: Optional[DateTime],
         auto_release_time: Optional[DateTime],
         key_name: Name,
-        run_time: Optional[Time] = None,
+        run_time: Optional[K3SRunTime] = None,
         k3s_version: Optional[Version] = None,
         _life_time: Number = Number(5)
     ):
@@ -321,56 +273,6 @@ class NodeCreationItem(ExpiredEntity):
         return False
 
 
-# class InstanceInfo(ExpiredEntity):
-#     def __init__(
-#         self,
-#         id: ID,
-#         status: Status,
-#         security_group_id: List[SecurityGroupID],
-#         instance_type: InstanceType,
-#         name: Name,
-#         hostname: Hostname,
-#         price: Price,
-#         image_id: ImageID,
-#         region_id: RegionID,
-#         zone_id: ZoneID,
-#         internet_pay_type: InternetPayType,
-#         pay_type: PayType,
-#         create_time: DateTime,
-#         os_name: Name,
-#         public_ip: List[IP],
-#         private_ip: Optional[IP],
-#         bandwidth_in: BandWidth,
-#         bandwidth_out: BandWidth,
-#         instance_expired_time: DateTime,
-#         auto_release_time: DateTime,
-#         key_name: Name,
-#         _life_time: Number = Number(5)
-#     ):
-#         self.id=id
-#         self.status=status
-#         self.security_group_id=security_group_id
-#         self.instance_type=instance_type
-#         self.name=name
-#         self.hostname=hostname
-#         self.price=price
-#         self.image_id=image_id
-#         self.region_id=region_id
-#         self.zone_id=zone_id
-#         self.internet_pay_type=internet_pay_type
-#         self.pay_type=pay_type
-#         self.create_time=create_time
-#         self.os_name=os_name
-#         self.public_ip=public_ip
-#         self.private_ip=private_ip
-#         self.bandwidth_in=bandwidth_in
-#         self.bandwidth_out=bandwidth_out
-#         self.instance_expired_time=instance_expired_time
-#         self.auto_release_time=auto_release_time
-#         self.key_name=key_name
-#         self._life_time=_life_time
-#         super().__init__(_life_time)
-
 class Namespace(ExpiredEntity):
     def __init__(
         self,
@@ -461,10 +363,10 @@ class Pod(ExpiredEntity):
     def __init__(
         self,
         name: Name,
-        node_name: NodeName,
+        node_name: Optional[NodeName],
         pod_status: PodStatus,
         age: DateTime,
-        pod_ip: IP,
+        pod_ip: Optional[IP],
         namespace: Name,
         restarts: RestartNumber,
         readiness_info: Optional[Info],
@@ -486,7 +388,7 @@ class NodeMeta(Entity):
         self,
         name: NodeName,
         status: NodeStatus,
-        run_time: Time,
+        run_time: K3SRunTime,
         k3s_version: Version,
         private_ip: IP,
         label: NodeLabel
@@ -774,6 +676,40 @@ class ContainerSetting(Entity):
         self.liveness_probe = liveness_probe
         self.ports = ports
 
+
+class DeploymentSetting(Entity):
+    def __init__(
+        self,
+        deployment_name: Name,
+        namespace_name: Name,
+        labels: LabelDict,
+        containers: List[ContainerSetting],
+        init_containers: Optional[List[ContainerSetting]],
+        node_name: Optional[Name],
+        node_selector: Optional[NodeSelectorDict],
+        replicas: Optional[Number],
+        restart_policy: Optional[RestartPolicy],
+        volumes: Optional[List[VolumeSetting]],
+        selector: LabelSelector,
+        dns_policy: Optional[DNSPolicy],
+        service_account_name: Optional[ServiceAccountName] = None
+    ) -> None:
+        self.deployment_name = deployment_name
+        self.namespace_name = namespace_name
+        self.labels = labels
+        self.containers = containers
+        self.init_containers = init_containers
+        self.node_name = node_name
+        self.node_selector = node_selector
+        self.replicas = replicas
+        self.restart_policy = restart_policy
+        self.volumes = volumes
+        self.selector = selector
+        self.dns_policy = dns_policy
+        self.service_account_name = service_account_name
+
+
+
 class JobSetting(Entity):
     def __init__(
         self,
