@@ -238,6 +238,9 @@ class K3SRunTime(ValueObject):
             self.value = value.total_seconds()
         else:
             self.value = float(value)
+    
+    def total_seconds(self)->float:
+        return self.value
 
 class Version(ExpiredValueObject):
     def __init__(self, value):
@@ -296,6 +299,19 @@ class ServiceType(ExpiredValueObject):
 class PodStatus(ExpiredValueObject):
     def __init__(self, value):
         super().__init__(value, None)
+    
+    def is_pending(self):
+        return self.value=='Pending'
+
+    def is_running(self):
+        return self.value=='Running'
+
+    def is_succeed(self):
+        return self.value=='Succeed'
+
+    def is_failed(self):
+        return self.value=='Failed'
+
 
 class DockerImageName(ExpiredValueObject):
     def __init__(self, value):
@@ -489,6 +505,12 @@ class NodeCreationStatus(ValueObject):
     def is_deleted(self):
         return self.value=='Deleted'
 
+    def is_succeed(self):
+        return self.value=='Succeed'
+
+    def is_failed(self):
+        return self.value=='Failed'
+
 class AccountID(ValueObject):
     pass
 
