@@ -6,7 +6,10 @@ from vpc_control_ao.infrastructure.converter import (
     condition_converter,
     instance_info_converter,
     command_setting_detail_converter,
-    command_host_converter
+    command_host_converter,
+    command_item_converter,
+    command_request_converter,
+    command_setting_detail_converter
 )
 from vpc_control_ao.domain.value_obj import(
     CommandResponseStatus,
@@ -14,6 +17,7 @@ from vpc_control_ao.domain.value_obj import(
     DeltaTime
 )
 from ..domain.entity import (
+    DeploymentSetting,
     DatapipeResponse,
     DatapipeDataInfo,
     DatapipeServerInfo,
@@ -123,7 +127,7 @@ from ..domain.value_obj import (
     InstanceTypeStatusCategory,
     ReclaimPolicy,
     SecurityGroupID,
-    Time,
+    K3SRunTime,
     InstanceID,
     Number,
     InternetPayType,
@@ -147,6 +151,7 @@ from ..domain.value_obj import (
     NetworkScheme
 )
 from .do import (
+    DeploymentSettingDO,
     DatapipeHostDO,
     DatapipeResponseDO,
     DatapipeDataInfoDO,
@@ -198,31 +203,6 @@ from .do import (
     KeyToPathDO
 )
 
-# class ConditionConverter(Converter):
-#     def to_entity(self, do: ConditionDO):
-#         return Condition(
-#             min_cpu_num = Number(do.min_cpu_num),
-#             max_cpu_num = Number(do.max_cpu_num),
-#             min_memory_size = Size(do.min_memory_size),
-#             max_memory_size = Size(do.max_memory_size),
-#             min_gpu_num = Number(do.min_gpu_num),
-#             max_gpu_num = Number(do.max_gpu_num),
-#             min_gpu_memory_size = Size(do.min_gpu_memory_size),
-#             max_gpu_memory_size = Size(do.max_gpu_memory_size)
-#         )
-#     def to_do(self, x: Condition):
-#         return ConditionDO(
-#             min_cpu_num = None if x.min_cpu_num is None else x.min_cpu_num.get_value(),
-#             max_cpu_num = None if x.max_cpu_num is None else x.max_cpu_num.get_value(),
-#             min_memory_size = None if x.min_memory_size is None else x.min_memory_size.get_value(),
-#             max_memory_size = None if x.max_memory_size is None else x.max_memory_size.get_value(),
-#             min_gpu_num = None if x.min_gpu_num is None else x.min_gpu_num.get_value(),
-#             max_gpu_num = None if x.max_gpu_num is None else x.max_gpu_num.get_value(),
-#             min_gpu_memory_size = None if x.min_gpu_memory_size is None else x.min_gpu_memory_size.get_value(),
-#             max_gpu_memory_size = None if x.max_gpu_memory_size is None else x.max_gpu_memory_size.get_value()
-#         )
-# condition_converter = ConditionConverter()
-
 class NodeUserSettingConverter(Converter):
     def to_entity(self, do: NodeUserSettingDO):
         return NodeUserSetting(
@@ -309,7 +289,7 @@ class NodeInfoConverter(Converter):
             node_expired_time=None if do.node_expired_time is None else DateTime(do.node_expired_time),
             auto_release_time=None if do.auto_release_time is None else DateTime(do.auto_release_time),
             key_name=Name(do.key_name),
-            run_time=None if do.run_time is None else Time(do.run_time),
+            run_time=None if do.run_time is None else K3SRunTime(do.run_time),
             k3s_version=None if do.k3s_version is None else Version(do.k3s_version),
             _life_time=Number(do._life_time)
         )
@@ -393,93 +373,7 @@ class ReleaseNodeInfoConverter(Converter):
         )
 release_node_info_converter = ReleaseNodeInfoConverter()
 
-# class InstanceInfoConverter(Converter):
-#     def to_entity(self, do: InstanceInfoDO):
-#         return InstanceInfo(
-#             id = ID(do.id),
-#             status = Status(do.status),
-#             security_group_id = [SecurityGroupID(m) for m in do.security_group_id],
-#             instance_type = InstanceType(do.instance_type),
-#             name = Name(do.name),
-#             hostname = Hostname(do.hostname),
-#             price = Price(do.price),
-#             image_id = ImageID(do.image_id),
-#             region_id = RegionID(do.region_id),
-#             zone_id = ZoneID(do.zone_id),
-#             internet_pay_type = InternetPayType(do.internet_pay_type),
-#             pay_type = PayType(do.pay_type),
-#             create_time = DateTime(do.create_time),
-#             os_name = Name(do.os_name),
-#             public_ip = [IP(m) for m in do.public_ip],
-#             private_ip = None if do.private_ip is None else IP(do.private_ip),
-#             bandwidth_in = BandWidth(do.bandwidth_in),
-#             bandwidth_out = BandWidth(do.bandwidth_out),
-#             instance_expired_time = DateTime(do.instance_expired_time),
-#             auto_release_time = DateTime(do.auto_release_time),
-#             key_name = Name(do.key_name),
-#             _life_time = Number(do._life_time)
-#         )
-#     def to_do(self, x: InstanceInfo):
-#         return InstanceInfoDO(
-#             id = None if x.id is None else x.id.get_value(),
-#             status = None if x.status is None else x.status.get_value(),
-#             security_group_id = None if x.security_group_id is None else [m.get_value() for m in x.security_group_id],
-#             instance_type = None if x.instance_type is None else x.instance_type.get_value(),
-#             name = None if x.name is None else x.name.get_value(),
-#             hostname = None if x.hostname is None else x.hostname.get_value(),
-#             price = None if x.price is None else x.price.get_value(),
-#             image_id = None if x.image_id is None else x.image_id.get_value(),
-#             region_id = None if x.region_id is None else x.region_id.get_value(),
-#             zone_id = None if x.zone_id is None else x.zone_id.get_value(),
-#             internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
-#             pay_type = None if x.pay_type is None else x.pay_type.get_value(),
-#             create_time = None if x.create_time is None else x.create_time.get_value(),
-#             os_name = None if x.os_name is None else x.os_name.get_value(),
-#             public_ip = None if x.public_ip is None else [m.get_value() for m in x.public_ip],
-#             private_ip = None if x.private_ip is None else x.private_ip.get_value(),
-#             bandwidth_in = None if x.bandwidth_in is None else x.bandwidth_in.get_value(),
-#             bandwidth_out = None if x.bandwidth_out is None else x.bandwidth_out.get_value(),
-#             instance_expired_time = None if x.instance_expired_time is None else x.instance_expired_time.get_value(),
-#             auto_release_time = None if x.auto_release_time is None else x.auto_release_time.get_value(),
-#             key_name = None if x.key_name is None else x.key_name.get_value(),
-#             _life_time = None if x._life_time is None else x._life_time.get_value()
-#         )
-# instance_info_converter = InstanceInfoConverter()
 
-# class InstanceUserSettingConverter(Converter):
-#     def to_entity(self, do: InstanceUserSettingDO):
-#         return InstanceUserSetting(
-#             name = Name(do.name),
-#             password = Password(do.password),
-#             image_id = ImageID(do.image_id),
-#             region_id = RegionID(do.region_id),
-#             exclude_instance_types = [InstanceType(m) for m in do.exclude_instance_types],
-#             user_data = Data(do.user_data),
-#             internet_pay_type = Type(do.internet_pay_type),
-#             amount = InstanceAmount(do.amount),
-#             bandwidth_in = BandWidth(do.bandwidth_in),
-#             bandwidth_out = BandWidth(do.bandwidth_out),
-#             disk_size = Size(do.disk_size),
-#             key_name = Name(do.key_name),
-#             inner_connection = Bool(do.inner_connection)
-#         )
-#     def to_do(self, x: InstanceUserSetting):
-#         return InstanceUserSettingDO(
-#             name = None if x.name is None else x.name.get_value(),
-#             password = None if x.password is None else x.password.get_value(),
-#             image_id = None if x.image_id is None else x.image_id.get_value(),
-#             region_id = None if x.region_id is None else x.region_id.get_value(),
-#             exclude_instance_types = None if x.exclude_instance_types is None else [m.get_value() for m in x.exclude_instance_types],
-#             user_data = None if x.user_data is None else x.user_data.get_value(),
-#             internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
-#             amount = None if x.amount is None else x.amount.get_value(),
-#             bandwidth_in = None if x.bandwidth_in is None else x.bandwidth_in.get_value(),
-#             bandwidth_out = None if x.bandwidth_out is None else x.bandwidth_out.get_value(),
-#             disk_size = None if x.disk_size is None else x.disk_size.get_value(),
-#             key_name = None if x.key_name is None else x.key_name.get_value(),
-#             inner_connection = None if x.inner_connection is None else x.inner_connection.get_value()
-#         )
-# instance_user_setting_converter = InstanceUserSettingConverter()
 
 class NamespaceConverter(Converter):
     def to_entity(self, do: NamespaceDO):
@@ -498,6 +392,8 @@ class NamespaceConverter(Converter):
         )
 namespace_converter = NamespaceConverter()
 
+
+
 class SecretConverter(Converter):
     def to_entity(self, do: SecretDO):
         return Secret(
@@ -515,6 +411,8 @@ class SecretConverter(Converter):
         )
 secret_converter = SecretConverter()
 
+
+
 class SecretUserSettingConverter(Converter):
     def to_entity(self, do: SecretUserSettingDO):
         return SecretUserSetting(
@@ -532,6 +430,8 @@ class SecretUserSettingConverter(Converter):
         )
 secret_user_setting_converter = SecretUserSettingConverter()
 
+
+
 class ConfigMapConverter(Converter):
     def to_entity(self, do: ConfigMapDO):
         return ConfigMap(
@@ -549,6 +449,8 @@ class ConfigMapConverter(Converter):
         )
 config_map_converter = ConfigMapConverter()
 
+
+
 class ConfigMapUserSettingConverter(Converter):
     def to_entity(self, do: ConfigMapUserSettingDO):
         return ConfigMapUserSetting(
@@ -568,6 +470,8 @@ class ConfigMapUserSettingConverter(Converter):
         )
 config_map_user_setting_converter = ConfigMapUserSettingConverter()
 
+
+
 class DeploymentConverter(Converter):
     def to_entity(self, do: DeploymentDO):
         return Deployment(
@@ -587,14 +491,16 @@ class DeploymentConverter(Converter):
         )
 deployment_converter = DeploymentConverter()
 
+
+
 class PodConverter(Converter):
     def to_entity(self, do: PodDO):
         return Pod(
             name = Name(do.name),
-            node_name = NodeName(do.node_name),
+            node_name = None if do.node_name is None else NodeName(do.node_name),
             pod_status = PodStatus(do.pod_status),
             age = DateTime(do.age),
-            pod_ip = IP(do.pod_ip),
+            pod_ip = None if do.pod_ip is None else IP(do.pod_ip),
             namespace = Name(do.namespace),
             restarts = RestartNumber(do.restarts),
             readiness_info = Info(do.readiness_info),
@@ -614,6 +520,8 @@ class PodConverter(Converter):
         )
 pod_converter = PodConverter()
 
+
+
 class IngressConverter(Converter):
     def to_entity(self, do: IngressDO):
         return Ingress(
@@ -637,6 +545,8 @@ class IngressConverter(Converter):
         )
 ingress_converter = IngressConverter()
 
+
+
 class ServiceConverter(Converter):
     def to_entity(self, do: ServiceDO):
         return Service(
@@ -660,6 +570,8 @@ class ServiceConverter(Converter):
         )
 service_converter = ServiceConverter()
 
+
+
 class PodContainerConverter(Converter):
     def to_entity(self, do: PodContainerDO):
         return PodContainer(
@@ -677,12 +589,14 @@ class PodContainerConverter(Converter):
         )
 pod_container_converter = PodContainerConverter()
 
+
+
 class NodeMetaConverter(Converter):
     def to_entity(self, do: NodeMetaDO):
         return NodeMeta(
             name = NodeName(do.name),
             status = NodeStatus(do.status),
-            run_time = Time(do.run_time),
+            run_time = K3SRunTime(do.run_time),
             k3s_version = Version(do.k3s_version),
             private_ip = IP(do.private_ip),
             label = NodeLabel(do.label)
@@ -986,6 +900,44 @@ class ContainerSettingConverter(Converter):
         )
 container_setting_converter = ContainerSettingConverter()
 
+
+
+
+class DeploymentSettingConverter(Converter):
+    def to_entity(self, do: DeploymentSettingDO):
+        return DeploymentSetting(
+            deployment_name=Name(do.deployment_name),
+            namespace_name=Name(do.namespace_name),
+            labels=LabelDict(do.labels),
+            containers=[container_setting_converter.to_entity(c) for c in do.containers],
+            init_containers=None if do.init_containers is None else [container_setting_converter.to_entity(i) for i in do.init_containers],
+            node_name = None if do.node_name is None else Name(do.node_name),
+            node_selector=None if do.node_selector is None else NodeSelectorDict(do.node_selector),
+            replicas=None if do.replicas is None else Number(do.replicas),
+            restart_policy=None if do.restart_policy is None else RestartPolicy(do.restart_policy),
+            volumes = None if do.volumes is None else [volume_setting_converter.to_entity(i) for i in do.volumes],
+            selector = label_selector_converter.to_entity(do.selector),
+            dns_policy = None if do.dns_policy is None else DNSPolicy(do.dns_policy),
+            service_account_name = None if do.service_account_name is None else ServiceAccountName(do.service_account_name)
+        )
+    def to_do(self, x: DeploymentSetting):
+        return DeploymentSettingDO(
+            deployment_name=x.deployment_name.get_value(),
+            namespace_name = x.namespace_name.get_value(),
+            labels=x.labels.get_value(),
+            containers=[container_setting_converter.to_do(m) for m in x.containers],
+            init_containers=None if x.init_containers is None else [container_setting_converter.to_do(m) for m in x.init_containers],
+            node_name=None if x.node_name is None else x.node_name.get_value(),
+            node_selector=None if x.node_selector is None else x.node_selector.get_value(),
+            replicas=None if x.replicas is None else x.replicas.get_value(),
+            restart_policy=None if x.restart_policy is None else x.restart_policy.get_value(),
+            volumes=None if x.volumes is None else [volume_setting_converter.to_do(m) for m in x.volumes],
+            selector = label_selector_converter.to_do(x.selector),
+            dns_policy=None if x.dns_policy is None else x.dns_policy.get_value(),
+            service_account_name=None if x.service_account_name is None else ServiceAccountName(x.service_account_name)
+        )
+deployment_setting_converter = DeploymentSettingConverter()
+
 class JobSettingConverter(Converter):
     def to_entity(self, do: JobSettingDO):
         return JobSetting(
