@@ -23,7 +23,7 @@ class NodeUserSettingDO(BaseModel):
     disk_size: int=20
     bandwidth_in: int=200
     bandwidth_out: int=1
-    image_id: str='centos_8_5_x64_20G_alibase_20220303.vhd'
+    image_id: str='ubuntu_20_04_x64_20G_alibase_20221107.vhd'
     node_type: str='worker'
     postfix: bool=True
     diff_instance_type: bool=False
@@ -134,10 +134,10 @@ class DeploymentDO(BaseModel):
 
 class PodDO(BaseModel):
     name: str
-    node_name: str
+    node_name: Optional[str]
     pod_status: str
     age: Union[str, datetime.timedelta]
-    pod_ip: str
+    pod_ip: Optional[str]
     namespace: str
     restarts: str
     readiness_info: Optional[str]
@@ -175,9 +175,6 @@ class ReleaseNodeInfoDO(BaseModel):
     region_id: str
     instance_id: str
 
-# class ReleaseInstanceInfoDO(BaseModel):
-#     region_id: str
-#     instance_id: str
 
 
 
@@ -309,6 +306,23 @@ class ContainerSettingDO(BaseModel):
     ports: Optional[List[ContainerPortDO]] = None
 
 
+class DeploymentSettingDO(BaseModel):
+    deployment_name: str
+    namespace_name: str
+    labels: Dict
+    containers: List[ContainerSettingDO]
+    init_containers: Optional[List[ContainerSettingDO]] = None
+    node_name: Optional[str] = None
+    node_selector: Optional[Dict] = None
+    replicas: Optional[int] = None
+    restart_policy: Optional[str] = None
+    volumes: Optional[List[VolumeSettingDO]] = None
+    selector: LabelSelectorDO
+    dns_policy: Optional[str] = None
+    service_account_name: Optional[str] = None
+
+
+
 class JobSettingDO(BaseModel):
     job_name: str
     namespace_name: str
@@ -317,10 +331,10 @@ class JobSettingDO(BaseModel):
     init_containers: Optional[List[ContainerSettingDO]]
     node_name: Optional[str] = None
     node_selector: Optional[Dict] = None
-    parallelism: int = 1
-    ttl_seconds_after_finished: int = 600
-    restart_policy: str = 'Never'
-    backoff_limit: int = 2
+    parallelism: Optional[int] = 1
+    ttl_seconds_after_finished: Optional[int] = 600
+    restart_policy: Optional[str] = 'Never'
+    backoff_limit: Optional[int] = 2
     volumes: Optional[List[VolumeSettingDO]] = None
     selector: Optional[LabelSelectorDO] = None
     dns_policy: Optional[str] = None
